@@ -13,6 +13,7 @@
 #include "requestcontext_p.h"
 
 #include <KPublicTransport/Attribution>
+#include <KPublicTransport/Location>
 
 #include <QFlags>
 #include <QJsonObject>
@@ -30,7 +31,6 @@ namespace KPublicTransport {
 
 class JourneyReply;
 class JourneyRequest;
-class Location;
 class LocationReply;
 class LocationRequest;
 class StopoverReply;
@@ -90,6 +90,8 @@ class KPUBLICTRANSPORT_EXPORT AbstractBackend
     Q_PROPERTY(QString customCaCertificate WRITE setCustomCaCertificate)
     /** PKCS#12 client certificate bundle. */
     Q_PROPERTY(QString pkcs12 WRITE setPkcs12)
+    /** Static operator URL. */
+    Q_PROPERTY(QUrl operatorUrl MEMBER m_operatorUrl)
 public:
     AbstractBackend();
     virtual ~AbstractBackend();
@@ -127,6 +129,12 @@ public:
      */
     [[nodiscard]] QStringList preferredLanguages() const;
 
+    /** Static operator URL, to be set on Line objects in results.
+     *  Use this for backends that do not provide this dynamically in their responses.
+     *  @since 25.12
+     */
+    [[nodiscard]] QUrl operatorUrl() const;
+
     /** Called after all settings have been set on this backend. */
     virtual void init();
 
@@ -148,13 +156,19 @@ public:
      */
     [[nodiscard]] virtual Capabilities capabilities() const;
     /** Checks if this backend has @p capability. */
-    [[nodiscard]] inline bool hasCapability(Capability capability) const { return capabilities() & capability; };
+    [[nodiscard]] bool hasCapability(Capability capability) const { return capabilities() & capability; };
 
     /** Returns the static attribution information for this backend. */
     [[nodiscard]] Attribution attribution() const;
     /** Sets the static attribution information for this backend. */
     void setAttribution(const Attribution &attr);
 
+    /** Returns the location types this backend can query.
+     *  This is used to ensure geocoding queries all relevant backends.
+     *  @since 25.12
+     */
+    [[nodiscard]] virtual Location::Types supportedLocationTypes() const = 0;
+
     /** Type of query.
      *  @see needsLocationQuery
      */
@@ -220,12 +234,12 @@ public:
 
 protected:
     /** Helper function to call non-public Reply API. */
-    template <typename T, typename ...Args> inline static void addResult(T *reply, Args&&... args)
+    template <typename T, typename ...Args> static void addResult(T *reply, Args&&... args)
     {
         reply->addResult(std::forward<Args>(args)...);
     }
 
-    template <typename T> inline void addError(T *reply, Reply::Error error, const QString &errorMsg) const
+    template <typename T> void addError(T *reply, Reply::Error error, const QString &errorMsg) const
     {
         reply->addError(this, error, errorMsg);
     }
@@ -234,24 +248,24 @@ protected:
 
     /** Extract the request context for the current backend from @p request. */
     template <typename ReqT>
-    [[nodiscard]] inline RequestContext requestContext(const ReqT &request) const
+    [[nodiscard]] RequestContext requestContext(const ReqT &request) const
     {
         return request.context(this);
     }
     /** Extract the backend-specific data from the request context for the current backend from @p request. */
     template <typename ReqT>
-    [[nodiscard]] inline QVariant requestContextData(const ReqT &request) const
+    [[nodiscard]] QVariant requestContextData(const ReqT &request) const
     {
         return request.context(this).backendData;
     }
 
     /** Set request context for retrieving the next set of results for a stopover or journey query. */
-    template <typename RepT> inline void setNextRequestContext(RepT *reply, const QVariant &data) const
+    template <typename RepT> void setNextRequestContext(RepT *reply, const QVariant &data) const
     {
         reply->setNextContext(this, data);
     }
     /** Set request context for retrieving the previous set of results for a stopover or journey query. */
-    template <typename RepT> inline void setPreviousRequestContext(RepT *reply, const QVariant &data) const
+    template <typename RepT> void setPreviousRequestContext(RepT *reply, const QVariant &data) const
     {
         reply->setPreviousContext(this, data);
     }
@@ -306,6 +320,8 @@ private:
     QList<QSslCertificate> m_customCaCerts;
     QSslCertificate m_clientCert;
     QSslKey m_privateKey;
+
+    QUrl m_operatorUrl;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(AbstractBackend::Capabilities)
