@@ -12,6 +12,7 @@
 
 #include <KPublicTransport/Feature>
 #include <KPublicTransport/Line>
+#include <KPublicTransport/Load>
 #include <KPublicTransport/Location>
 #include <KPublicTransport/RentalVehicle>
 
@@ -63,11 +64,14 @@ private:
     struct RouteData {
         Route route;
         std::vector<Feature> features;
+        Load::Category occupancy = Load::Unknown;
     };
     RouteData parseLine(const QJsonObject &obj) const;
     RouteData parseRoute(const QJsonObject &obj) const;
     RouteData parseInlineRoute(const QJsonObject &obj) const;
     RouteData detectAndParseRoute(const QJsonObject &obj) const;
+    /// common part of parsing an OTP2 Stopover object (EstimatedCall for Entur)
+    [[nodiscard]] Stopover parseStoptime(const QJsonObject &obj) const;
     Stopover parseDeparture(const QJsonObject &obj) const;
     void parseDeparturesForStop(const QJsonObject &obj, std::vector<Stopover> &deps) const;
     JourneySection parseJourneySection(const QJsonObject &obj) const;
