@@ -35,20 +35,23 @@ class KPUBLICTRANSPORT_EXPORT StopoverQueryModel : public AbstractQueryModel
     /** Whether querying for earlier journey is possible. */
     Q_PROPERTY(bool canQueryPrevious READ canQueryPrevious NOTIFY canQueryPrevNextChanged)
 
+    /** Enable automatic update of the model content every minute. */
+    Q_PROPERTY(bool autoUpdate READ autoUpdate WRITE setAutoUpdate NOTIFY autoUpdateChanged)
+
 public:
     explicit StopoverQueryModel(QObject *parent = nullptr);
     ~StopoverQueryModel() override;
 
-    StopoverRequest request() const;
+    [[nodiscard]] StopoverRequest request() const;
     void setRequest(const StopoverRequest &req);
 
-    bool canQueryNext() const;
+    [[nodiscard]] bool canQueryNext() const;
     /** Search for later journeys.
      *  Has no effect if canQueryNext() returns @c false.
      */
     Q_INVOKABLE void queryNext();
 
-    bool canQueryPrevious() const;
+    [[nodiscard]] bool canQueryPrevious() const;
     /** Search for earlier journeys.
      *  Has no effect if canQueryPrevious() returns @c false.
      */
@@ -60,16 +63,20 @@ public:
     };
     Q_ENUM(Roles)
 
-    int rowCount(const QModelIndex &parent) const override;
-    QVariant data(const QModelIndex &index, int role) const override;
-    QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = {}) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
     /** The current model content. */
-    const std::vector<Stopover>& departures() const;
+    [[nodiscard]] std::vector<Stopover> departures() const;
+
+    [[nodiscard]] bool autoUpdate() const;
+    void setAutoUpdate(bool enabled);
 
 Q_SIGNALS:
     void requestChanged();
     void canQueryPrevNextChanged();
+    void autoUpdateChanged();
 
 private:
     friend class StopoverQueryModelPrivate;
